@@ -10,14 +10,16 @@
 #'
 #' @param excl Character string (or vector of character strings) denoting parameters to exclude. Used in conjunction with \code{params} argument to select parameters of interest.
 #'
-#' @param ISB Ignore Square Brackets (ISB). Logical specifying whether square brackets should be ignored in the \code{params} and \code{excl} arguments. If \code{TRUE}, square brackets are ignored - input from \code{params} and \code{excl} are otherwise matched exactly. If \code{FALSE}, square brackets are not ignored - input from \code{params} and \code{excl} are matched using grep, which can take arguments in regular expression format. This allows partial names to be used when specifying parameters of interest.
+#' @param ISB Ignore Square Brackets (ISB). Logical specifying whether square brackets should be ignored in the \code{params} and \code{excl} arguments. If \code{TRUE}, square brackets are ignored. If \code{FALSE}, square brackets are not ignored.  This allows partial names to be used when specifying parameters of interest. Use \code{exact} argument to specify whether input from \code{params} and \code{excl} arguments should be matched exactly.
+#'
+#' @param exact Logical specifying whether input from \code{params} and \code{excl} arguments should be matched exactly (after ignoring square brackets if \code{ISB = FALSE}). If \code{TRUE}, input from \code{params} and \code{excl} are matched exactly (after taking \code{ISB} argument into account). If \code{FALSE}, input from \code{params} and \code{excl} are matched using regular expression format (after taking \code{ISB} argument into account).
 #'
 #' @param func Function to be performed on MCMC output. When output of specified function is greater than length 1, an extra dimension is added. For instance, output of length 3 for a parameter with dimensions 2x2 results in a 2x2x3 output. Functions that produce output with dimensionality greater than 1 are not permitted. \code{func} is ignored when \code{type = 'chains'}.
 #'
 #' @param type Character string specifying whether to return summary information (calculated based on \code{func} argument) or posterior chains. Valid options are \code{'summary'} and \code{'chains'}. When \code{type = 'chains'}, the \code{'func'} argument is ignored. When \code{type = 'chains'}, posterior chains are concatenated and stored in the last dimension in the array for each element (parameter) of the list.
 #'
 #' @section Details:
-#' \code{object} argument can be a \code{stanfit} object (\code{rstan} package), a \code{stanreg} object (\code{rstanarm} package), a \code{brmsfit} object (\code{brms} package), an \code{mcmc.list} object (\code{coda} package), an \code{R2jags} model object (\code{R2jags} package), a \code{jagsUI} model object (\code{jagsUI} package), or a matrix containing MCMC chains (each column representing MCMC output for a single parameter, rows representing iterations in the chain). The function automatically detects the object type and proceeds accordingly.
+#' \code{object} argument can be a \code{stanfit} object (\code{rstan} package), a \code{stanreg} object (\code{rstanarm} package), a \code{brmsfit} object (\code{brms} package), an \code{mcmc.list} object (\code{coda} and \code{rjags} packages), \code{mcmc} object (\code{coda} and \code{nimble} packages), \code{list} object (\code{nimble} package), an \code{R2jags} model object (\code{R2jags} package), a \code{jagsUI} model object (\code{jagsUI} package), or a matrix containing MCMC chains (each column representing MCMC output for a single parameter, rows representing iterations in the chain). The function automatically detects the object type and proceeds accordingly.
 #'
 #' @examples
 #' #Load data
@@ -28,18 +30,19 @@
 #' @export
 
 MCMCpstr <- function(object,
-                   params = 'all',
-                   excl = NULL,
-                   ISB = TRUE,
-                   func = mean,
-                   type = 'summary')
+                     params = 'all',
+                     excl = NULL,
+                     ISB = TRUE,
+                     exact = TRUE,
+                     func = mean,
+                     type = 'summary')
 {
   #SORTING BLOCK
   if (methods::is(object, 'matrix'))
   {
-    object2 <- MCMCchains(object, params, excl, ISB, mcmc.list = FALSE)
+    object2 <- MCMCchains(object, params, excl, ISB, exact = exact, mcmc.list = FALSE)
   } else {
-    object2 <- MCMCchains(object, params, excl, ISB, mcmc.list = TRUE)
+    object2 <- MCMCchains(object, params, excl, ISB, exact = exact, mcmc.list = TRUE)
   }
 
   if (coda::is.mcmc.list(object2) == TRUE)
@@ -104,8 +107,14 @@ MCMCpstr <- function(object,
     ind <- which(un[i] == names)
 
     #determine how many ',' and therefore how many dimensions for parameter
-    dims <- length(strsplit(onames[ind[1]], split = ',', fixed = TRUE)[[1]])
-
+    #if only one ind, there should only be one dim
+    if (length(ind) == 1)
+    {
+      dims <- 1
+    } else {
+      dims <- length(strsplit(onames[ind[1]], split = ',', fixed = TRUE)[[1]])
+    }
+    
     #scalar or vector
     if (dims == 1)
     {
